pub fn finish_v1_docs(router: ApiRouter) -> RouterExpand description
Build the OpenAPI spec for the mounted routes and attach the docs routes; every serve mode must route through this.
pub fn finish_v1_docs(router: ApiRouter) -> RouterBuild the OpenAPI spec for the mounted routes and attach the docs routes; every serve mode must route through this.