struct ErrorResponse {
error: String,
}Expand description
API error response
Fields
error: StringTrait Implementations
Sourceimpl Debug for ErrorResponse
impl Debug for ErrorResponse
Sourceimpl JsonSchema for ErrorResponse
impl JsonSchema for ErrorResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read morefn always_inline_schema() -> bool
fn always_inline_schema() -> bool
👎Deprecated:
Use inline_schema() instead
Only included for backward-compatibility - use
inline_schema() instead“. Read moreAuto Trait Implementations
impl Freeze for ErrorResponse
impl RefUnwindSafe for ErrorResponse
impl Send for ErrorResponse
impl Sync for ErrorResponse
impl Unpin for ErrorResponse
impl UnsafeUnpin for ErrorResponse
impl UnwindSafe for ErrorResponse